'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('@babel/runtime/helpers/extends');
var _objectSpread = require('@babel/runtime/helpers/objectSpread2');
var _objectWithoutProperties = require('@babel/runtime/helpers/objectWithoutProperties');
var core = require('@westpac/core');
var PropTypes = require('prop-types');
require('@babel/runtime/helpers/defineProperty');

function _interopDefault (e) { return e && e.__esModule ? e : { 'default': e }; }

var PropTypes__default = /*#__PURE__*/_interopDefault(PropTypes);

var _excluded$1 = ["state"];
// Component
// ==============================

var Badge$1 = function Badge(_ref) {
  _ref.state;
      var rest = _objectWithoutProperties(_ref, _excluded$1);

  return core.jsx("span", rest);
};
// Styles
// ==============================


var badgeStyles = function badgeStyles(_, _ref3) {
  var look = _ref3.look;

  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS,
      TYPE = _useBrand.TYPE;

  return _objectSpread(_objectSpread({
    label: core.getLabel('badge'),
    display: 'inline-block',
    border: '1px solid',
    borderRadius: '0.75rem',
    fontSize: '0.875rem',
    lineHeight: 1,
    minWidth: '0.625rem',
    padding: '0.25rem 0.4375rem',
    textAlign: 'center',
    verticalAlign: 'baseline',
    whiteSpace: 'nowrap',
    color: look === 'faint' ? COLORS.muted : '#fff',
    backgroundColor: look === 'faint' ? '#fff' : COLORS[look],
    borderColor: look === 'faint' ? COLORS.border : COLORS[look]
  }, TYPE.bodyFont[700]), {}, {
    ':empty': {
      display: 'none'
    },
    '@media print': {
      color: '#000',
      backgroundColor: '#fff',
      border: '1px solid #000'
    }
  });
}; // ==============================
// Attributes
// ==============================


var badgeAttributes = function badgeAttributes() {
  return null;
};
// Exports
// ==============================


var defaultBadge = {
  component: Badge$1,
  styles: badgeStyles,
  attributes: badgeAttributes
};

var pkg = {
	name: "@westpac/badge",
	version: "1.1.0",
	description: "Small, coloured UI items used to highlight a number count",
	homepage: "https://gel.westpacgroup.com.au/design-system",
	repository: "https://github.com/WestpacGEL/GEL/tree/master/components/badge",
	blender: {
		recipe: "blender/recipe.js"
	},
	components: [
		{
			name: "Badge",
			src: "Badge.js"
		}
	],
	author: "Westpac GEL Team <gel@westpac.com.au>",
	contributors: [
		{
			name: "Dominik Wilkowski",
			email: "Hi@Dominik-Wilkowski.com",
			url: "https://dominik-wilkowski.com"
		},
		{
			name: "Jonathan Stening",
			email: "info@jonathanstening.com",
			url: "http://jonathanstening.com"
		},
		{
			name: "Jeremy Ortiz",
			email: "jeremy@jeremyortiz.io",
			url: "https://www.jeremyortiz.io/"
		},
		{
			name: "Flore Laforge",
			email: "florelaforge@gmail.com",
			url: "http://florelaforge.com/"
		}
	],
	license: "GPL-3.0+",
	scripts: {
		start: "PACKAGE_NAME=badge NODE_ENV=development webpack server --config ../../helpers/example/start.webpack.config.js",
		test: "exit 0 # start-server-and-test start http://localhost:8080 test:all",
		"test:dev": "start-server-and-test start http://localhost:8080 test:test-dev",
		"test:all": "yarn test:integration",
		"test:integration": "cypress run",
		"test:test-dev": "cypress open"
	},
	main: "dist/westpac-badge.cjs.js",
	module: "dist/westpac-badge.esm.js",
	dependencies: {
		"@babel/runtime": "^7.14.8",
		"@westpac/core": "^2.2.0",
		"prop-types": "^15.7.2"
	},
	peerDependencies: {
		react: "^17.0.2"
	},
	devDependencies: {
		"@westpac/body": "^1.4.1",
		"@westpac/button": "^1.3.0",
		cypress: "^8.0.0",
		react: "^17.0.2",
		"start-server-and-test": "^1.12.6"
	}
};

var _excluded = ["look", "value", "overrides"];
// Component
// ==============================

var Badge = function Badge(_ref) {
  var look = _ref.look,
      value = _ref.value,
      componentOverrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, _excluded);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var defaultOverrides = {
    Badge: defaultBadge
  };

  var state = _objectSpread({
    look: look,
    value: value,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$B = _overrideReconciler.Badge,
      Badge = _overrideReconciler$B.component,
      badgeStyles = _overrideReconciler$B.styles,
      badgeAttributes = _overrideReconciler$B.attributes;

  return core.jsx(Badge, _extends({}, rest, {
    state: state
  }, badgeAttributes(state), {
    css: badgeStyles(state)
  }), value);
}; // ==============================
// Types
// ==============================

Badge.propTypes = {
  /**
   * Badge look
   */
  look: PropTypes__default['default'].oneOf(['primary', 'hero', 'neutral', 'faint', 'success', 'info', 'warning', 'danger']).isRequired,

  /**
   * Badge text
   */
  value: PropTypes__default['default'].string.isRequired,

  /**
   * The override API
   */
  overrides: PropTypes__default['default'].shape({
    Badge: PropTypes__default['default'].shape({
      styles: PropTypes__default['default'].func,
      component: PropTypes__default['default'].elementType,
      attributes: PropTypes__default['default'].func
    })
  })
};
var defaultProps = {
  look: 'neutral'
};
Badge.defaultProps = defaultProps;

exports.Badge = Badge;
